@@ -14,13 +14,13 @@ module Tins
   require 'tins/memoize'
   require 'tins/minimize'
   require 'tins/module_group'
+  require 'tins/named_set'
   require 'tins/null'
   require 'tins/once'
   require 'tins/p'
   require 'tins/partial_application'
   require 'tins/range_plus'
   require 'tins/require_maybe'
-  require 'tins/round'
   require 'tins/secure_write'
   require 'tins/shuffle'
   require 'tins/string_camelize'
@@ -48,8 +48,11 @@ module Tins
   require 'tins/annotate'
   require 'tins/token'
   require 'tins/dslkit'
+  require 'tins/case_predicate'
+  require 'tins/implement'
   if defined? ::Encoding
     require 'tins/string_byte_order_mark'
   end
+  require 'tins/complete'
 end
 require 'tins/alias'
